/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.example.resources;

import net.craftforge.essential.example.persistence.CrudDao;
import net.craftforge.essential.example.persistence.EntityManagerProvider;
import org.apache.commons.codec.binary.Base64;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.servlet.http.HttpServletRequest;

/**
 * A persistent resource has access to an entity manager and other
 * convenient data access objects.
 *
 * @author Christian Bick
 * @since 30.08.11
 */
public class PersistentResource<T> {

    private static Logger LOGGER = LoggerFactory.getLogger(PersistentResource.class);

    @Inject
    private HttpServletRequest request;

    protected CrudDao<T> getCrudDao() {
        return new CrudDao<T>(createEntityManager());
    }

    protected EntityManager createEntityManager() {
        String clientName = request.getRemoteHost();
        String databaseName = new String(Base64.encodeBase64(clientName.getBytes())).replace("=", "");
        LOGGER.info("Assigning database {} for client {}", databaseName, clientName);
        return EntityManagerProvider.createEntityManager(databaseName);
    }

}
